Plugin: JS9Divs

### Visibility of JS9 Plugin Divs

JS9 plugins can be added statically to a web page by specifying a div element with the plugin class as an attribute, e.g:

      <div class="JS9Menubar"></div>
      <div class="JS9"></div>
      <div style="margin-top: 2px;">
      <div class="JS9Colorbar"></div>

This plugin allows you to hide or show these in-page plugins. It works by setting the CSS visibility property on the divs. Note that invisible elements will still take up space on the web page.